---
title: "AI for healthcare"
author: "Jean Feydy"
institute: ""
topic: ""
theme: "metropolis"
colortheme:
fonttheme:
fontsize: 11pt
linkcolor: black
urlcolor: blue
linkstyle: bold
aspectratio: 169
titlegraphic: 
logo:
date:
section-titles: false
toc: false
---


## Who am I? A short CV

Background in **mathematics** and **data sciences**:

```{=latex}
\vspace*{-.25cm}
\begin{description}
\setlength\itemsep{-.5em}
\item[2012--2016] ENS Paris, mathematics.
\item[2014--2015] M2 mathematics, vision, learning at ENS Cachan.
\item[2016--2019] PhD thesis in \textcolor{red!80!black}{\textbf{medical imaging}} with Alain Trouvé at ENS Cachan.
\item[2019--2021] \textcolor{red!80!black}{\textbf{Geometric deep learning}} with Michael Bronstein at Imperial College.
\item[2021+] \textcolor{red!80!black}{\textbf{Medical data analysis}} in the HeKA INRIA team (Paris).
\end{description}
\vspace*{.4cm}
```

Close ties with `\textbf{\textcolor{red!80!black}{healthcare}}`{=latex}:


```{=latex}
\vspace*{-.25cm}
\begin{description}
\setlength\itemsep{-.5em}
\item[2015\phantom{+}] Image denoising with \textbf{Siemens Healthcare} in Princeton.
\item[2019+] MasterClass AI--Imaging, for \textbf{radiology interns} in the University of Paris.
\item[2020+] Colloquium on \textbf{Medical imaging in the AI era} at the Paris Brain Institute.
\end{description}
```

## My motivation: medical data analysis


`\vspace*{.5cm}`{=latex}

![](images/pipeline/pipeline.png){ width=100% }

`\vspace*{.25cm}`{=latex}

Three main **characteristics**:

- **Heterogeneous data**: patient history, images, etc.
- Small stratified samples: 10 -- 1 000 patients per group.
- Dealing with **outliers** and the **heavy tails** of our distributions is a priority.



## Two main applications -- on large real-life datasets

**Computational anatomy.** 3D medical scans:

- 100k triangles to represent a brain surface.
- 512x512x512 $\simeq$ 130M voxels for a typical 3D image.


**Public health.** Over the last decade, medical datasets have **blown up** in size:

- Clinical trials: **1k patients**, controlled environment.
- UK Biobank: **500k people**, curated data.
- French Health Data Hub: **70M people**, full social security data since ~2000.

Medical doctors, pharmacists and governments need scalable methods.

## Some research interests


::: columns

:::: {.column width=30%}

`\begin{center}`{=latex}

![](images/interests/lungs.png){height=4cm}

Optimal transport \
for shape registration.

`\end{center}`{=latex}

::::

:::: {.column width=30%}

`\begin{center}`{=latex}

![](images/interests/proteins.png){height=4cm}

Geometric deep learning \
for protein docking.

`\end{center}`{=latex}

::::

:::: {.column width=30%}

`\begin{center}`{=latex}

![](images/interests/carte_vitale.jpg){height=4cm}

Survival analysis \
for pharmaco-vigilance.

`\end{center}`{=latex}

::::

:::


## Three points of view on machine learning and AI

```{=latex}
	\vspace{.3cm}
	At the intersection of three communities~:
	\begin{itemize}
  \item \textbf{AI experts} in Paris, London...
        %\vspace{.15cm}
  \item \textbf{Students} at the ENS, the MVA, Epita.
        %\vspace{.15cm}
  \item \textbf{Medical doctors} among colleagues, friends and family.
	\end{itemize}
	\vspace{.6cm}

	\begin{tabular}{r@{}l}
	\textbf{AI in healthcare} : massive gap between~
	& what we \textbf{know}, \\
	& what we \textbf{hope},\\
	& what we \textbf{fear}.
	\end{tabular}

    \begin{center}
    ~\\
    What do \textbf{you} think?
    \end{center}
\end{frame}

\begin{frame}{``Artificial intelligence'' is a misleading term}
	
	\vspace*{.5cm}

	\centerline{
	\begin{tabular}{ccc}
		\begin{minipage}{.3\linewidth}
			\includegraphics[height=4cm]{images/IA/Metropolis2.jpg}
		\end{minipage}
		&
		\begin{minipage}{.3\linewidth}
			\includegraphics[height=4cm]{images/IA/hal.jpeg}
		\end{minipage}
		&\quad
		\begin{minipage}{.3\linewidth}
			\includegraphics[height=4cm]{images/IA/terminator.jpg}
		\end{minipage}
	\end{tabular}
	}

	\vspace*{.5cm}

	\begin{center}
	AI seduces, questions, protects or threatens\dots{}
	\textbf{But doesn't explain much~!}

	Among experts, researchers always talk about \BR{models},\\
	discuss their underlying \textbf{hypotheses} and study their \textbf{properties}.

	The aim of this class is to give you a structured perspective on the field.
	\end{center}
\end{frame}

\begin{frame}{Objectives of the class}
```

1. Present a **quick overview** of models that you are likely to encounter.

2. Highlight their underlying **hypotheses**, **strengths** and **weaknesses**.

3. Provide you with **clear guidelines** on the use of different tools and theories.

4. **Discuss** the realities of applied machine learning.


## Today


**1. AI = model + data:**

  - The curse of dimensionality -- or why ML is not "just statistics".
  - Example: three levels of analysis in anatomy.


`\vspace{.25cm}`{=latex}

**2. How can I choose a good model?**

  - The map is not the territory.
  - Example 1: the sphere of triangles.
  - Example 2: style transfer with convolutional neural networks.

`\vspace{.25cm}`{=latex}

**3. Overview of the class:**
  
  - What's coming next?
  - Setup on the computers.


# 1. AI = model + data

## What is a dataset?

`\begin{center}`{=latex}

![](images/dataset/dataset_original.pdf){ height=65% }

**Supervised learning**  $=$  **Regression**. \
We look for a formula $\text{F}(\text{x}_\text{1}, \dots, \text{x}_{\text{D}})$ of the D variables\
that best approximates an important quantity ($\heartsuit$).

`\end{center}`{=latex}


## A simple model: linear regression

`\begin{center}`{=latex}

![](images/dataset/linear_regression.pdf){ height=65% }

We choose the weights **a**, **b**, $\dots$, **f** \
by minimizing a least squares error. \
 \

`\end{center}`{=latex}


## The standard setting of low-dimensional statistics `\cite{celestialorbit}`{=latex}

`\begin{center}\vspace*{.2cm}`{=latex}

![](images/planetary_orbit_parameters.pdf){ height=65% }

First applications to astronomy, \
with **hundreds of observations** \
on a `\BR{handful of variables}`{=latex}. \

`\end{center}`{=latex}


## Problem: medicine isn't XIXth century astronomy

`\begin{center}`{=latex}

![](images/dataset/correlation.pdf){ height=65% }

With **lots of information** about **few patients**, \
we quickly "discover" spurious correlations. \
This is known as **overfitting**.

`\end{center}`{=latex}


## Significant (XKCD 882)

`\begin{center}`{=latex}

![](images/XKCD_882/1.png){ height=97% }

`\end{center}`{=latex}

## Significant (XKCD 882)

`\begin{center}`{=latex}

![](images/XKCD_882/2.png){ height=97% }

`\end{center}`{=latex}

## Significant (XKCD 882)

`\begin{center}`{=latex}

![](images/XKCD_882/3.png){ height=97% }

`\end{center}`{=latex}

## Significant (XKCD 882)

`\begin{center}`{=latex}

![](images/XKCD_882/4.png){ height=97% }

`\end{center}`{=latex}


## The curse of dimensionality


`\begin{center}`{=latex}
Having access to **more patients** is usually a **good** thing. \
But getting `\textcolor{red!80!black}{\textbf{more information}}`{=latex} about each patient is `\textcolor{red!80!black}{\textbf{very dangerous}}`{=latex}.

In the previous example: knowing the **color** of the candy\
led the (imprudent) scientists to **over-interpret** a random fluctuation.


\
\
**Machine learning** is about doing **reliable** statistics \
in this dangerous setting.

`\end{center}`{=latex}

## We must regularize our decision rules -- using sparsity

`\begin{center}`{=latex}

![](images/dataset/correlation.pdf){ height=65% }

A **sparse** model will select 5 or 10 important columns.\
This is useful to handle **tabular data** (XGBoost...) \
or **identify sources** in signal processing (Lasso...).

`\end{center}`{=latex}

## We must regularize our decision rules -- using a domain-specific structure

`\begin{center}`{=latex}

![](images/dataset/group_regression.pdf){ height=65% }

A **structured** model will leverage the **geometry of the data**. \
Think about the main **food groups** or the \
ATC classification for **medical drugs**.

`\end{center}`{=latex}

# A first example: medical imaging

## A medical image is a massive lump of data

`\begin{center}`{=latex}

![](images/bitmap/3D.png){ height=65% }

Each pixel is a **column** in our dataset! \

We observe `\BR{millions to billions of variables}`{=latex} \
on cohorts of **a few thousand patients**.

`\end{center}`{=latex}

## Sampling the full space of medical images is impossible

```{=latex}

	\vspace{-.2cm}
	\hspace{-.2cm}

	\begin{center}
	\begin{tikzpicture}[scale=.6]
	\begin{scope}[xshift = 0cm]
		\draw[->,>=latex,thick] (-.5,0)--(4.7,0);
		\foreach \x in {0,1,2,3,4}
		{
			\pgfmathtruncatemacro{\mycol}{10+20*\x}
			\fill[color=green!\mycol!blue] (\x,0) circle (0.1cm);
		}
		\node[anchor=mid] at (2,-1) {1 number};
		\node[anchor=mid] at (2,-1.9) {~$\rightarrow$~5 samples};
	\end{scope}

	\begin{scope}[xshift = 7.5cm]
		\draw[->,>=latex,thick] (-.5,0)--(4.7,0);
		\draw[->,>=latex,thick] (0,-.5)--(0,4.7);
		\foreach \x in {0,1,2,3,4}
		\foreach \y in {0,1,2,3,4}
		{
			\pgfmathtruncatemacro{\mycola}{10+20*\x}
			\pgfmathtruncatemacro{\mycolb}{90-20*\y}
			\fill[color=green!\mycola!blue!\mycolb!red] (\x,\y) circle (0.1cm);
		}
		\node[anchor=mid] at (2,-1) {2 numbers};
		\node[anchor=mid] at (2,-1.9) {$\rightarrow$~$\text{5}^\text{2}$ samples};
	\end{scope}


	\begin{scope}[xshift = 15cm]
		\node[anchor=center] at (2,2) {\includegraphics[width=3.2cm]{images/Cardiac_mri_slice_bionerd.jpg}} ;
		\node[anchor=mid] at (2,-1) {$\text{128}\cdot \text{128}$ numbers};
		\node[anchor=mid] at (2,-1.9) {$\rightarrow$~$\text{5}^{\text{128}\cdot \text{128}}$ samples};
	\end{scope}
	\end{tikzpicture}
    \end{center}

	\vspace{.2cm}
	\begin{center}
		The set of all 2D/3D images is \textbf{way too large}\\
		to be sampled with a satisfying accuracy.
	\end{center}
```

## First remark: we cannot rely on sparsity


`\begin{center}`{=latex}

A good radiology exam does not rely exclusively on **5 or 10 pixels**. \
We must learn how to **group pixels** in relevant bundles.

![](images/voisinages/heart_naif.png){ height=70% }

`\end{center}`{=latex}


## What do you see on a chest image? `\cite{heart_raw, heart_pop}`{=latex}

```{=latex}
\vspace{-.43cm}
\begin{align*}
	\onslide<2->{ \text{1. Pixels} }&&
	\onslide<3->{ \text{2. Anatomy} } &&
	\onslide<5->{ \text{3. Function} }
\end{align*}

\begin{figure}
	\centering %
	\only<1-2>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/heart_raw.png} }%
	\only<3>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/heart_segmented.png} }%
	\only<4>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/dev_coeurs_2.png} }%
	\only<5>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_0.png} }%
	\only<6>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_1.png} }%
	\only<7>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_2.png} }%
	\only<8>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_3.png} }%
	\only<9>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_4.png} }%
	\only<10>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_5.png} }%
	\only<11>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_6.png} }%
	\only<12>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_7.png} }%
	\only<13>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_8.png} }%
	\only<14>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_9.png} }%
	\only<15>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/hearts/hearts_0.png} }%
	\only<16->{ 
		\includegraphics[height=.55\textheight]{images/voisinages/heart_models.png}
		\begin{center}
		Simplifying a bit, each level of analysis corresponds to\\
		a way of \textbf{grouping pixels} with their neighbors.
		\end{center}
		}%
\end{figure}
```



## 1st level: a pixel grid

```{=latex}
	\begin{columns}[t]
		\begin{column}{.45\linewidth}

		\begin{center}
			\vspace*{.4cm}

			\includegraphics[width=.8\linewidth]{images/bitmap/mini_bitmap.png}%

			$\text{N}_\text{x} \times \text{N}_\text{y} \times \text{N}_\text{z}$ array of pixels.
		\end{center}
			
		\end{column}
		\begin{column}{.5\linewidth}

			\textbf{Bitmap} images and volumes:
			\begin{itemize}
				\item \texttt{.bmp}, \texttt{.png}, \texttt{.jpg} 
				\item Standard in \textbf{radiology}.\\[.5cm]
				\item[$+$] Ordered memory structure.
				\item[$+$] Explicit neighborhoods.
				\item[$+$] Fast \textbf{convolutions}. \\[.5cm]
				\item[$\rightarrow$] \textbf{Texture} analysis.
				\item[$\rightarrow$] Organ \textbf{segmentation}.
				\item[$\rightarrow$] Pattern \textbf{detection}. 
			\end{itemize}
		\end{column}
	\end{columns}
```


## 2nd level: point clouds and 3D surfaces `\cite{heart_raw}`{=latex}

```{=latex}
\begin{columns}[t]
	\begin{column}{.45\linewidth}

	\begin{center}
		\vspace*{1cm}

		\includegraphics[width=.8\linewidth]{images/bitmap/mesh.png}%

		$\text{N}_{\text{points}} \times \text{3}$ array of $(\text{x},\text{y},\text{z})$ coordinates.
	\end{center}
		
	\end{column}
	\begin{column}{.5\linewidth}

		\textbf{Clouds of points} ($\pm$ triangles):
		\begin{itemize}
			\item \texttt{.svg}
			\item Standard for \textbf{video games}.\\[.5cm]
			\item[$+$] Compact representation.
			\item[$+$] High precision geometry.
			\item[$+$] \textbf{Easy to deform}. \\[.5cm]
			\item[$\rightarrow$] \textbf{3D visualization}.
			\item[$\rightarrow$] Anatomical \textbf{atlas}.
			\item[$\rightarrow$] \textbf{Shape} analysis.
		\end{itemize}
	\end{column}
\end{columns}	
```

## 3rd level: biomechanical and/or physiological model `\cite{heart_pop}`{=latex}

```{=latex}
\begin{columns}[t]
	\begin{column}{.45\linewidth}

	\begin{center}
		\vspace*{.5cm}

		\includegraphics[height=4cm]{images/hearts/hearts_1.png}%

		Volumetric mesh, \\graph of interactions.
	\end{center}
		
	\end{column}
	\begin{column}{.5\linewidth}

		\textbf{Mechanical/biological model}:
		\begin{itemize}
			\item Finite elements, networks.
			\item Standard for \textbf{CAD}.\\[.5cm]
			\item[$+$] Prior \textbf{knowledge}.
			\item[$+$] \textbf{Robust} to noise.
			\item[$+$] \textbf{Realistic} behaviour. \\[.5cm]
			\item[$\rightarrow$] \textbf{Physiological} interpretation.
			\item[$\rightarrow$] \textbf{Infer} what cannot be seen (blood flow).
			\item[$\rightarrow$] \textbf{Simulate} a surgery.
		\end{itemize}
	\end{column}
\end{columns}
```

## To summarize

We must combine a **statistical regression** method with a **relevant model**.

In medical imaging, we may work with:

1. A 2D or 3D **pixel grid**.
2. An array of $(\text{x},\text{y},\text{z})$ **coordinates**.
3. A **web** of complex interactions.
4. Everything at once!

`\begin{center}`{=latex}
In most cases, we will define a large `\textcolor{red!80!black}{\textbf{structured formula}}`{=latex}:

```{=latex}
\vspace*{-.5cm}
\begin{align*}
	\text{image} \xrightarrow{~~~\text{F}~~~} \text{F}\,(\text{image}) \simeq \text{diagnostic}
\end{align*}
```

**F** is a parametric computing **architecture** \
$\simeq$ **model** to fit $\simeq$ **network** to train.

`\end{center}`{=latex}


# 2. How can I choose a good model?

## A model is like a map: a warped and partial view of the world `~~\cite{scratchinghead,mercator}`{=latex}

`\vspace*{.5cm}\begin{center}`{=latex}

![](images/world-maps/world_maps.pdf){ width=95% }

`\end{center}\vspace*{.25cm}`{=latex}


## The map is not the territory


`\vspace*{.5cm}\begin{center}`{=latex}
A map is not the territory it represents, but, if correct, \
it has a **similar structure** to the territory, \
which accounts for its **usefulness**.\
\
-- Alfred Korzybski, 1933.
`\end{center}\vspace*{.25cm}`{=latex}


## On exactitude in science -- Jorge Luis Borges, 1946, translated by Andrew Hurley.

`\justifying`{=latex}

...In that empire, the art of cartography attained such 
`\textcolor{red!80!black}{\textbf{perfection}}`{=latex} that the map of a
single **province** occupied the entirety of a **city**, and the map of the **empire**, the entirety
of a **province**. In time, those unconscionable maps no longer satisfied, and the
cartographers guilds struck `\textcolor{red!80!black}{\textbf{a map of the empire whose size was that of the empire}}`{=latex}, and
which coincided point for point with it. 

The following generations, who were not so
fond of the study of cartography as their forebears had been, saw that 
`\textcolor{red!80!black}{\textbf{that vast map was useless}}`{=latex}, 
and not without some pitilessness was it, that they delivered it up to the
inclemencies of sun and winters. In the **deserts** of the West, still today, there are
tattered **ruins of that map**, inhabited by animals and beggars; in all the land there is
no other relic of the disciplines of geography.

`\begin{flushright}`{=latex}
-- Suarez Miranda, *Viajes de varones prudentes*, Libro IV,Cap. XLV, Lerida, 1658
`\end{flushright}`{=latex}


## What is a good model?

A good map should:

- `\textcolor{red!80!black}{\textbf{Highlight}}`{=latex} the relevant key points and roads. \
  This is a **task-specific** objective (car, bike...).

- **Hide** unnecessary information to reduce clutter: `\textcolor{red!80!black}{\textbf{the lighter, the better}}`{=latex}. \
  Heavy maps *will* be discarded by the next generation.

- Be **accurate** -- up to a required **tolerance**. \
  There is a `\textcolor{red!80!black}{\textbf{tradeoff}}`{=latex} here: think of the metro map!

- Be **transparent** about `\textcolor{red!80!black}{\textbf{omissions and distortions}}`{=latex}. \
  This is the main **trap** that we should not forget.




## What is a good model?


`\begin{center}`{=latex}
**All** these points apply to ML models:

- **Highlight** the stuff that matters.
- **Discard** the rest.
- Be **accurate** -- up to a sensible tolerance.
- Be `\textcolor{red!80!black}{\textbf{transparent}}`{=latex} and `\textcolor{red!80!black}{\textbf{honest}}`{=latex}.


Of course, raw "performance" results do matter: **accuracy** is a real thing.

But most importantly, a good model should be **legible** and enable **creativity**.

`\end{center}`{=latex}






# Example 1: The sphere of triangles

## Surprisingly enough, our story starts with... Menhirs!

`\begin{center}`{=latex}

![](images/kendall/menhirs_hd.jpg){height=95%}

`\end{center}`{=latex}



## More precisely: with the distribution of megaliths in the Land's End peninsula

::: columns

:::: {.column width=30%}

`\begin{center}`{=latex}

![](images/kendall/megaliths.png){height=5cm}

52 Menhir locations.

`\end{center}`{=latex}

::::

:::: {.column width=68%}

`\begin{center}`{=latex}

![](images/kendall/cornouailles.jpg){height=5cm}

Cornwall, in South-West England.

`\end{center}`{=latex}

::::


:::


`\begin{center}`{=latex}

Can you see **alignments** here? Some people do. \
Many authors have claimed that these **ley lines** demarcate \
"Earth energies" and/or serve as guides for alien spacecraft.

`\end{center}`{=latex}

## Understanding triangle shapes

Back in 1974, this problem motivated David Kendall to ask a question:

`\begin{center}`{=latex}

Assuming that I draw 52 points at random in a square... \
How many **flat triangles** (say, with a 180° $\pm$ 1° angle) am I going to observe?

`\end{center}`{=latex}

\
This prompted a remarkable series of papers:

- *The diffusion of shape*, Kendall, 1977.
- *Alignments in two-dimensional **random sets of points***, Kendall and Kendall, 1980.
- *Simulating the **ley hunter***, Broadbent, 1980.
- *Shape manifolds, Procrustean metrics, and complex projective spaces*, Kendall, 1984.

And the the birth of modern shape analysis.


## Step 1: Working with shapes up to similarities `\cite{klingenberg2015analyzing}`{=latex}

`\begin{center}`{=latex}

![](images/kendall/procrustes.png){height=95%}

`\end{center}`{=latex}


## Step 2: The space of triangles up to similarities is two-dimensional

::: columns

:::: {.column width=30%}

`\begin{center}\vspace*{.1cm}`{=latex}

![](images/kendall/abc_z.pdf){height=6cm}

Send A to $(\text{-1}, \text{0})$ \
and B to $(\text{+1}, \text{0})$.

`\end{center}`{=latex}

::::

:::: {.column width=68%}

`\begin{center}`{=latex}

![](images/kendall/vue_xi.png){height=6cm}

Identify $\text{z} \in \mathbb{C}\cup\{\infty\}$ \
with all non-degenerate triangle shapes.
`\end{center}`{=latex}

::::

:::

## Step 3: Up to a clever change of coordinates: this is actually a sphere!

`\begin{center}`{=latex}

![](images/kendall/vue_cavaliere.png){height=95%}

`\end{center}`{=latex}

## The two poles correspond to the direct and indirect equilateral triangles

`\begin{center}`{=latex}

![](images/kendall/vue_i.png){height=95%}

`\end{center}`{=latex}


## The Equator corresponds to the set of flat triangles

`\begin{center}`{=latex}

![](images/kendall/vue_0.png){height=95%}

`\end{center}`{=latex}


## First properties of this map

This representation respects the main `\BR{symmetries}`{=latex} of the set of triangles:

- The sets of **isoceles triangles** with respect to A, B and C correspond to \
  three **great circles** that are equally spaced with each other.

- **Axial symmetries** correspond to a North-South inversion across the Equator.

- The Equator of flat triangles + the meridians of isoceles triangles \
  cut the sphere in **12 pieces**. These exactly correspond to \
  the 6 permutations of the vertices ABC $\times$ $\{$ the identity or an axial symmetry $\}$.


But there is more!

## Metric properties of the spherical embedding

`\begin{center}`{=latex}

$$
\textbf{K} : (\text{A},\text{B},\text{C}) \in \mathbb{R}^{\text{3}\times\text{2}} 
\textbackslash \{\text{A}=\text{B}=\text{C}\} ~~\mapsto~~ 
\textbf{K}(\text{A},\text{B},\text{C}) \in \mathbb{R}^\text{3} \
$$


denotes the **Kendall embedding** from the set of non-degenerate \
triangles to the sphere of center $(\text{0}, \text{0}, \text{0})$ and diameter 1. \
(It has an OK-ish expression using cos and sin.)

Then, straightforward computations show that:
$$
	\min_{\SIM{\text{similarity S}}} 
	\| \SIM{\text{S}(\ABC{\text{A}})} - \DEF{\text{D}} \|^2_{\mathbb{R}^\text{2}}
	+
	\| \SIM{\text{S}(\ABC{\text{B}})} - \DEF{\text{E}} \|^2_{\mathbb{R}^\text{2}}
	+
	\| \SIM{\text{S}(\ABC{\text{C}})} - \DEF{\text{F}} \|^2_{\mathbb{R}^\text{2}}
~=~
\text{Var}(\DEF{\text{D},\text{E},\text{F}})
\,\cdot\,
\| \textbf{K}(\ABC{\text{A},\text{B},\text{C}}) - \textbf{K}(\DEF{\text{D},\text{E},\text{F}})\|^2_{\mathbb{R}^\text{3}}
$$

The **chord distance on the sphere** of Kendall corresponds to \
the **Euclidean distance** on triplets of points in the plane, **up to similarities**.
`\end{center}`{=latex}


## Statistical properties of the spherical embedding

`\vspace*{.5cm}`{=latex}

::: columns

:::: {.column width=63%}

`\begin{center}`{=latex}

![](images/kendall/tri_1.png){height=4cm}

A, B, C are drawn according to an **isotropic** \
Gaussian distribution on the plane.

`\end{center}`{=latex}

::::

:::: {.column width=37%}

`\begin{center}`{=latex}

![](images/kendall/stats_1.png){height=4cm}

Empirical histogram on the \
sphere of triangle shapes.
`\end{center}`{=latex}

::::

:::


## Statistical properties of the spherical embedding

`\vspace*{.5cm}`{=latex}

::: columns

:::: {.column width=63%}

`\begin{center}`{=latex}

![](images/kendall/tri_2.png){height=4cm}

A, B, C are drawn according to a **non-isotropic** \
Gaussian distribution on the plane.

`\end{center}`{=latex}

::::

:::: {.column width=37%}

`\begin{center}`{=latex}

![](images/kendall/stats_2.png){height=4cm}

Empirical histogram on the \
sphere of triangle shapes.
`\end{center}`{=latex}

::::

:::



## Statistical properties of the spherical embedding

`\vspace*{.5cm}`{=latex}

::: columns

:::: {.column width=63%}

`\begin{center}`{=latex}

![](images/kendall/tri_4.png){height=4cm}

A, B, C are drawn according to a **non-isotropic** \
Gaussian distribution on the plane.

`\end{center}`{=latex}

::::

:::: {.column width=37%}

`\begin{center}`{=latex}

![](images/kendall/stats_4.png){height=4cm}

Empirical histogram on the \
sphere of triangle shapes.
`\end{center}`{=latex}

::::

:::

## Summary

`\begin{center}`{=latex}
Kendall showed that the space of **triangles** is best understood as a **sphere** \
for **topological**, **geometric** and **statistical** reasons.

\
You cannot "unsee" this elegant result.

\
Most importantly, his theorem showed that **shapes** \
naturally belong to a **curved** geometric space.
`\end{center}`{=latex}

## This idea is at the heart of modern shape analysis software `\cite{kilian2007geometric}`{=latex}


`\begin{center}`{=latex}

![](images/elastic/kilian.jpg){height=80%}

Geodesics in spaces of elephants and skeletons.

`\end{center}`{=latex}

## This idea is at the heart of modern shape analysis software `\cite{von2016optimized}`{=latex}


`\begin{center}`{=latex}

![](images/elastic/barycenter.jpg){height=80%}

Barycentric interpolation in a space of hands.

`\end{center}`{=latex}


# Example 2: Style transfer with convolutional neural networks


## Remember that picture? `\cite{heart_raw}`{=latex}

```{=latex}
\vspace{-.43cm}
\begin{align*}
	\onslide<1->{ \text{1. Pixels} }&&
	\onslide<1->{ \text{2. Anatomy} } &&
	\onslide<1->{ \text{3. Function} }
\end{align*}

\begin{figure}
	\centering %
	\includegraphics[height=.55\textheight]{images/voisinages/heart_models.png}
	\begin{center}
	Let's talk about the \textbf{first way} of \textbf{grouping pixels} with their neighbors.
	\end{center}
\end{figure}
```

## Filtering, also known as the "convolution product"

```{=latex}
\textbf{Convolution} (i.e. weighted average of the neighboring pixels)~:\\
\hspace*{10mm} Cheap generalization of the \textbf{product} ``$\text{a}\cdot \xc{\text{x}}$'',\\
\hspace*{10mm} parameterized by the coefficients of a \textbf{small filter} $\varphi$.

\vspace{1cm}
\begin{center}
\begin{tabular}{ccccc}
	\begin{minipage}{1cm}
	\only<1>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_1.png} }
	\only<2>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_2.png} }
	\only<3>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_3.png} }
	\only<4>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_4.png} }
	\only<5>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_5.png} }
	\only<6>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_6.png} }
	\only<7>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_7.png} }
	\only<8>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_8.png} }
	\end{minipage}
	& 
	\begin{minipage}{1cm} \vspace{-.5cm} {\huge $~\star$ } \end{minipage}
	&
	\begin{minipage}{3cm}
	\only<1>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<2>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<3>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<4>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<5>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<6>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<7>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<8>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\end{minipage}
	& 
	\begin{minipage}{1cm} \vspace{.1cm} {\huge $~~=~~$ } \end{minipage}
		&
	\begin{minipage}{3cm}
	\only<1>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<2>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_2.png} }
	\only<3>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_3.png} }
	\only<4>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_4.png} }
	\only<5>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_5.png} }
	\only<6>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_6.png} }
	\only<7>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_7.png} }
	\only<8>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_8.png} }
	\end{minipage} \\
	$\varphi$ && $\xc{\text{x}}$ && \only<1-5>{$\varphi \star \xc{x}$}\only<6->{$|\varphi \star \xc{\text{x}}|$}
\end{tabular}
\end{center}
```

## A multi-scale prior on images

```{=latex}
\textbf{Wavelet} theory (1990$\sim$2010 ; Meyer, Mallat, Daubechies...)~:\\
\hspace*{10mm} Small filters + cascading zoom-out operations~\cite{mallatcnn}:

\vspace{.2cm}
\begin{center}
\includegraphics[width=.7\linewidth]{images/wavelet.png}
\end{center}

\begin{center}
\begin{tabular}{ccc}
	Image & $\longrightarrow$& Relevant coefficients \\
	$\simeq$~~``.wav'' Audio & $\longrightarrow$& Music score
\end{tabular}
\end{center}

\vspace{.2cm}
\begin{center}
	$\Longrightarrow~~~$ \textbf{JPEG2000} format, standard of the movie industry.
\end{center}
```


## Convolutional neural networks `\cite{hollandais}`{=latex}

`\begin{center}`{=latex}

![](images/CNN_archi.png){height=95%}

`\end{center}`{=latex}



## Convolutional Neural Networks as a data-driven "codec" for your data

```{=latex}
JPEG2000 relies on a model for natural images that is:
\begin{itemize}
	\tightlist
	\item Computationally cheap.
	\item Translation-equivariant.
	\item Encodes a \textbf{multi-scale} prior on natural images.
\end{itemize}

By \textbf{tuning its parameters} on a labeled database,\\
we get a \textbf{CNN} ~~=~~ domain-specific ``JPEG2020''.

\vspace{.2cm}
\begin{center}
\begin{tikzpicture}[scale=.9]

\draw[color=blue!40,very thick] (-3,-1) rectangle (0,2);
\draw[color=blue!40,->,>=latex,very thick] (0,.5)--(4,.5);
\node[anchor=mid] at (-1.5,.5) {$\xc{\text{x}}$};
\node[color=blue, anchor=south] at (2,.6) {CNN};

\begin{scope}[xshift = 4cm]
	\fill[color=blue!20] (1.5,0)--(1.5,1)--(.25,1) arc (90:180:.25)--(0,.25) arc (180:270:.25)--cycle;
	\node[color=blue!50!black, anchor=mid] at (.75,.5) {$\mu(\xc{\text{x}})$};
	\fill[color=blue!30] (1.5,0)--(3,0)--(3,1)--(1.5,1)--cycle;
	\node[color=blue!50!black, anchor=mid] at (2.25,.5) {$\text{m}(\xc{\text{x}})$};
	\fill[color=blue!40] (3,1)--(3,0)--(4.25,0) arc (-90:0:.25)--(4.5,.75) arc (0:90:.25)--cycle;
	\node[color=blue!50!black, anchor=mid] at (3.75,.5) {$\text{M}(\xc{\text{x}})$};
\end{scope}
\end{tikzpicture}
\end{center}

```



## An iconic application: Deep Art `\cite{yaroslav}`{=latex}

```{=latex}
%\vspace{.1cm}
\begin{center}
\begin{tikzpicture}[scale=.45]

\onslide<2->{
\begin{scope}[xshift=-4.8cm,yshift=3.5cm]
	\fill[color=blue!40] (-1.575/.5,-1.2/.5)--(1.575/.5,-1.2/.5)
						--(1.575/.5,1.2/.5)--(-1.575/.5,1.2/.5)--cycle;
	\only<2-8>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_0.png} } };
	\only<9>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_a.png} } };
	\only<10>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_d.png} } };
	\only<11>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_e.png} } };
	\only<12>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_f.png} } };
	\only<13>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_g.png} } };
	\only<14>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_h.png} } };
	\only<15>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_j.png} } };
	\only<16>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_k.png} } };
	\only<17>{ 
	\node[inner sep=0pt] at (0,0) { \includegraphics[width=3cm]{images/cats/style_i.png} } };
	\end{scope}
}
\onslide<3->{
\begin{scope}[xshift=9.3cm,yshift=3.5cm]
	\fill[color=green!40] (-1.575/.5,-1.2/.5)--(1.575/.5,-1.2/.5)
						--(1.575/.5,1.2/.5)--(-1.575/.5,1.2/.5)--cycle;
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=3cm]{images/cats/cat.jpg}};
\end{scope}
}

\onslide<7>{
\draw[->,>=latex,very thick,color=blue!33!green!40] (2.25,-1)--(2.25,-2); 
\begin{scope}[xshift=2cm,yshift=-6cm]
	\fill[color=blue!33!green!40] (-2.625/.5,-2/.5)--(2.625/.5,-2/.5)
						--(2.625/.5,2/.5)--(-2.625/.5,2/.5)--cycle;
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_0a.jpg}};
\end{scope}
}

\onslide<8->{
\draw[->,>=latex,very thick,color=blue!66!green!40] (2.25,-1)--(2.25,-2); 
\begin{scope}[xshift=2cm,yshift=-6cm]
	\fill[color=blue!66!green!40] (-2.625/.5,-2/.5)--(2.625/.5,-2/.5)
						--(2.625/.5,2/.5)--(-2.625/.5,2/.5)--cycle;
	\only<8>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_0b.jpg}}; }
	\only<9>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_a.jpg}}; }
	\only<10>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_d.jpg}}; }
	\only<11>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_e.jpg}}; }
	\only<12>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_f.jpg}}; }
	\only<13>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_g.jpg}}; }
	\only<14>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_h.jpg}}; }
	\only<15>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_j.jpg}}; }
	\only<16>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_k.jpg}}; }
	\only<17>{
	\node[inner sep=0pt] at (0,0) {\includegraphics[width=5cm]{images/cats/cat_i.jpg}}; }
\end{scope}
}

\onslide<4->{ \draw[->,>=latex,thick,color=blue!40] (-1.5,4.5)--(0,4.5); }
\onslide<4->{ \draw[->,>=latex,thick,color=green!40] (6,2.5)--(4.5,2.5); }

\begin{scope}[yshift=4cm]
	\onslide<4->{
	\fill[color=blue!20] (1.5,0)--(1.5,1)--(.25,1) arc (90:180:.25)--(0,.25) arc (180:270:.25)--cycle;
	\node[color=blue!50!black, anchor=mid] at (.75,.5) {$\mu$};
	}
	\onslide<4,8->{
	\fill[color=blue!30] (1.5,0)--(3,0)--(3,1)--(1.5,1)--cycle;
	\node[color=blue!50!black, anchor=mid] at (2.25,.5) {$\text{m}$};
	}
	\onslide<5-7>{
	\fill[color=blue!6] (1.5,0)--(3,0)--(3,1)--(1.5,1)--cycle;
	\node[color=blue!50!black!20, anchor=mid] at (2.25,.5) {$\text{m}$};
	}
	\onslide<4>{
	\fill[color=blue!40] (3,1)--(3,0)--(4.25,0) arc (-90:0:.25)--(4.5,.75) arc (0:90:.25)--cycle;
	\node[color=blue!50!black, anchor=mid] at (3.75,.5) {$\text{M}$};
	}
	\onslide<5->{
	\fill[color=blue!8] (3,1)--(3,0)--(4.25,0) arc (-90:0:.25)--(4.5,.75) arc (0:90:.25)--cycle;
	\node[color=blue!50!black!20, anchor=mid] at (3.75,.5) {$\text{M}$};
	}
\end{scope}
\begin{scope}[yshift=2cm]
	\onslide<4>{
	\fill[color=green!20] (1.5,0)--(1.5,1)--(.25,1) arc (90:180:.25)--(0,.25) arc (180:270:.25)--cycle;
	\node[color=green!50!black, anchor=mid] at (.75,.5) {$\mu$};
	}
	\onslide<5->{
	\fill[color=green!4] (1.5,0)--(1.5,1)--(.25,1) arc (90:180:.25)--(0,.25) arc (180:270:.25)--cycle;
	\node[color=green!50!black!20, anchor=mid] at (.75,.5) {$\mu$};
	}
	\onslide<4-7>{
	\fill[color=green!30] (1.5,0)--(3,0)--(3,1)--(1.5,1)--cycle;
	\node[color=green!50!black, anchor=mid] at (2.25,.5) {$\text{m}$};
	}
	\onslide<8->{
	\fill[color=green!6] (1.5,0)--(3,0)--(3,1)--(1.5,1)--cycle;
	\node[color=green!50!black!20, anchor=mid] at (2.25,.5) {$\text{m}$};
	}
	\onslide<4->{
	\fill[color=green!40] (3,1)--(3,0)--(4.25,0) arc (-90:0:.25)--(4.5,.75) arc (0:90:.25)--cycle;
	\node[color=green!50!black, anchor=mid] at (3.75,.5) {$\text{M}$};
	}
\end{scope}
\begin{scope}[yshift=-1cm]
	\onslide<6->{
	\fill[color=blue!20] (1.5,0)--(1.5,1)--(.25,1) arc (90:180:.25)--(0,.25) arc (180:270:.25)--cycle;
	\node[color=blue!50!black, anchor=mid] at (.75,.5) {$\mu$};
	}
	\onslide<8->{
	\fill[color=blue!30] (1.5,0)--(3,0)--(3,1)--(1.5,1)--cycle;
	\node[color=blue!50!black, anchor=mid] at (2.25,.5) {$\text{m}$};
	}
	\onslide<6-7>{
	\fill[color=green!30] (1.5,0)--(3,0)--(3,1)--(1.5,1)--cycle;
	\node[color=green!50!black, anchor=mid] at (2.25,.5) {$\text{m}$};
	}
	\onslide<6->{
	\fill[color=green!40] (3,1)--(3,0)--(4.25,0) arc (-90:0:.25)--(4.5,.75) arc (0:90:.25)--cycle;
	\node[color=green!50!black, anchor=mid] at (3.75,.5) {$\text{M}$};
	}
\end{scope}

\onslide<6->{ \draw[->,>=latex,thick,color=blue!40]  (.75,4)--(.75,0); }
\onslide<8->{ \draw[->,>=latex,thick,color=blue!40] (2.25,4)--(2.25,0); }
\onslide<6-7>{ \draw[->,>=latex,thick,color=green!40] (2.25,2)--(2.25,0); }
\onslide<6->{ \draw[->,>=latex,thick,color=green!40] (3.75,2)--(3.75,0); }

\end{tikzpicture}
\end{center}
```

## The dream application: image classification `\cite{wei2017mneuron}`{=latex}

`\begin{center}`{=latex}

Looking at $\xc{\text{CNN}(\,\xc{\text{x}}\,)} = [\,\mu(\xc{\text{x}})\, ,\, \text{m}(\xc{\text{x}}) \,,\, \text{M}(\xc{\text{x}})\,]$, \
can we **distinguish** seagulls from pandas?

What researchers have in mind:

![](images/single_layer.png){height=65%}

`\end{center}`{=latex}


## The limits of multiscale filtering `\cite{fooledai}`{=latex}


`\begin{center}`{=latex}
Standard CNNs perform **pattern detection** -- little more, little less:

**« $\mu(\xc{\text{x}})$ is reliable ; $\text{M}(\xc{\text{x}})$ really isn't. »**

`\vspace{.3cm}`{=latex}

![](images/imagenet_fooled_2.png){width=60%}

`\end{center}`{=latex}




# Overview of the class

## A geometric perspective on data sciences


`\vspace*{.5cm}`{=latex}

![](images/similarity_matrix.pdf){ width=100% }

`\vspace*{.25cm}`{=latex}


`\begin{center}`{=latex}
This class is about understanding **similarity metrics**.\
What are the implicit **priors** that they reflect?\
How can we manipulate them **efficiently**?
`\end{center}`{=latex}


## Overview of the class `~~\cite{umapprime}`{=latex}

`\vspace*{.5cm}\begin{center}`{=latex}

![](images/overview/overview_epita.pdf){ width=95% }

`\end{center}\vspace*{.25cm}`{=latex}


# References
